@@ -18,7 +18,7 @@ class SyncSolver:
     page : Page
         The playwright page to solve the reCAPTCHA on.
     timeout : int, optional
-        The timeout in seconds, by default 30.
+        The solve timeout in seconds, by default 30.
 
     Attributes
     ----------
@@ -35,7 +35,7 @@ class SyncSolver:
     Raises
     ------
     RecaptchaTimeoutError
-        If the timeout has been exceeded.
+        If the solve timeout has been exceeded.
     RecaptchaVersionError
         If the reCAPTCHA is not version 3.
     """
@@ -85,7 +85,7 @@ class SyncSolver:
         Parameters
         ----------
         timeout : Optional[int], optional
-            The timeout in seconds, by default 30.
+            The solve timeout in seconds, by default 30.
 
         Returns
         -------
@@ -95,11 +95,13 @@ class SyncSolver:
         Raises
         ------
         RecaptchaTimeoutError
-            If the timeout has been exceeded.
+            If the solve timeout has been exceeded.
         RecaptchaVersionError
             If the reCAPTCHA is not version 3.
         """
+        self.token = None
         self._page.on("response", self._extract_token)
+
         timeout = timeout or self._timeout
         start_time = time.time()
 
